==> haskell-random-shuffle-0.0.4-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-ELLhRvOJvYFGOP7aTEBwDW
key:                  random-shuffle-0.0.4-ELLhRvOJvYFGOP7aTEBwDW
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  ea51a296b13e7ac8e22c8897fc6a8d8b
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-8.10.4/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/random-shuffle-0.0.4
hs-libraries:         HSrandom-shuffle-0.0.4-ELLhRvOJvYFGOP7aTEBwDW
depends:
    MonadRandom-0.5.2-2nUTjAM7Zbp7PicrmakGmL base-4.14.1.0
    random-1.2.0-JaeEP4ACTucH0elcxqGZLW

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-shuffle-0.0.4-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-2SOKxrwPfqcEXdeb1Z6J5P
key:                  random-shuffle-0.0.4-2SOKxrwPfqcEXdeb1Z6J5P
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  1a16eab658429d58e99d5c4b3f8505eb
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-8.10.4/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/random-shuffle-0.0.4
hs-libraries:         HSrandom-shuffle-0.0.4-2SOKxrwPfqcEXdeb1Z6J5P
depends:
    MonadRandom-0.5.2-7b3Cuv3tA1eKZD4cPQqo7V base-4.14.1.0
    random-1.2.0-CmoPyF0lvWpAFFYiilSJBe

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
